@@ -1,7 +1,7 @@
 #'Backwards selection to build an error correction model
 #'
 #'Much like the ecm function, this builds an error correction model.
-#'However, it uses backwards selection to select the optimal predictors based on lowest AIC, rather than using all predictors.
+#'However, it uses backwards selection to select the optimal predictors based on lowest AIC or BIC, rather than using all predictors.
 #'ecmback has the same parameters and output as ecm.
 #'@param y The target variable
 #'@param xeq The variables to be used in the equilibrium term of the error correction model
@@ -10,18 +10,19 @@
 #'@return an lm object representing an error correction model using backwards selection
 #'@seealso \code{lm}
 #'@examples
-#'#Use ecm to predict Fed Funds Rate based on Unemployment Rate, Inflation, and GDP Growth
-#'data(FedData)
+#'#Use ecm to predict Wilshire 5000 index based on corporate profits, 
+#'#Federal Reserve funds rate, and unemployment rate
+#'data(Wilshire)
 #'
-#'#Use 2015-12-01 and earlier data to build models
-#'trn <- FedData[FedData$date<='2015-12-01',]
+#'#Use 2014-12-01 and earlier data to build models
+#'trn <- Wilshire[Wilshire$date<='2014-12-01',]
 #'
 #'#Use backwards selection to choose which predictors are needed 
-#'xeq <- xtr <- trn[c('UnemploymentRate', 'Inflation', 'GDPgrowth')]
-#'modelback <- ecmback(trn$FedFundsRate, xeq, xtr)
+#'xeq <- xtr <- trn[c('CorpProfits', 'FedFundsRate', 'UnempRate')]
+#'modelback <- ecmback(trn$Wilshire5000, xeq, xtr)
 #'print(modelback)
-#'#Backwards selection chose Unemployment Rate and Inflation in the transient term. 
-#'#Inflation and GDP Growth in the equilibrium term.
+#'#Backwards selection chose CorpProfits in the equilibrium term, 
+#'#CorpProfits and UnempRate in the transient term.
 #'
 #'@export
 #'@importFrom stats lm complete.cases step
@@ -46,10 +47,9 @@ ecmback <- function (y, xeq, xtr, criterion="AIC")
     }
     xeqnames <- paste0(xeqnames, "Lag1")
     xeq <- as.data.frame(xeq)
-    ifelse(ncol(xeq) > 1, xeq <- rbind(rep(NA, ncol(xeq)), 
-                                       xeq[1:(nrow(xeq) - 1), ]), xeq <- data.frame(c(NA, 
-                                                                                      xeq[1:(nrow(xeq) - 1), ])))
+    ifelse(ncol(xeq) > 1, xeq <- rbind(rep(NA, ncol(xeq)), xeq[1:(nrow(xeq) - 1), ]), xeq <- data.frame(c(NA, xeq[1:(nrow(xeq) - 1), ])))
   }
+  
   xtrnames <- paste0("delta", xtrnames)
   xtr <- as.data.frame(xtr)
   xtr <- data.frame(apply(xtr, 2, diff, 1))
@@ -64,12 +64,15 @@ ecmback <- function (y, xeq, xtr, criterion="AIC")
     x <- xtr
     names(x) <- xtrnames
   }
+  
   full <- lm(dy ~ ., data = x)
+  null <- lm(dy ~ yLag1, data = x)
   if(criterion=='AIC'){
     k=2
   } else if(criterion=='BIC'){
     k=log(nrow(x))
   }
-  ecm <- step(full, data = x, direction = "backward", k=k, trace=0)
+  
+  ecm <- step(full, data = x, scope = list(upper = full, lower = null), direction = "backward", k=k, trace=0)
   return(ecm)
 }
